summaryrefslogtreecommitdiffstats
path: root/Modules/threadmodule.c
diff options
context:
space:
mode:
authorSjoerd Mullender <sjoerd@acm.org>1993-12-03 16:54:45 (GMT)
committerSjoerd Mullender <sjoerd@acm.org>1993-12-03 16:54:45 (GMT)
commit66bca326cb727dbf42ac6ac613f0d76dd52ef905 (patch)
tree24b652ae1ded6b91c45a0ac25564d6a78cacf326 /Modules/threadmodule.c
parent57531fea90ca0afe9efdc70d3dce1a3eb153f03e (diff)
downloadcpython-66bca326cb727dbf42ac6ac613f0d76dd52ef905.zip
cpython-66bca326cb727dbf42ac6ac613f0d76dd52ef905.tar.gz
cpython-66bca326cb727dbf42ac6ac613f0d76dd52ef905.tar.bz2
Port to Solaris 2.3.
Diffstat (limited to 'Modules/threadmodule.c')
-rw-r--r--Modules/threadmodule.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/Modules/threadmodule.c b/Modules/threadmodule.c
index f22aa8c..40169a3 100644
--- a/Modules/threadmodule.c
+++ b/Modules/threadmodule.c
@@ -195,7 +195,7 @@ t_bootstrap(args_raw)
func = gettupleitem(args, 0);
arg = gettupleitem(args, 1);
res = call_object(func, arg);
- DECREF(arg); /* Matches the INCREF(arg) in thread_start_new_thread */
+ DECREF(args); /* Matches the INCREF(args) in thread_start_new_thread */
if (res == NULL) {
fprintf(stderr, "Unhandled exception in thread:\n");
print_error(); /* From pythonmain.c */